@@ -10,4 +10,9 @@ pub use nodes::{SqlLiteral};
 
 pub fn sql(sql_raw: &str) -> SqlLiteral {
     SqlLiteral::new(sql_raw.to_string())
-}
\ No newline at end of file
+}
+pub use traits::ArelAble;
+
+pub use arel_macro::arel;
+// derive 废弃
+// pub use arel_macro::Arel;
\ No newline at end of file
