@@ -1,17 +1,17 @@
 use serde_json::{Value as Json};
 use std::marker::PhantomData;
-use crate::traits::ModelAble;
+use crate::traits::ArelAble;
 use crate::statements::StatementAble;
 use crate::nodes::SqlLiteral;
 use crate::methods;
 
 #[derive(Clone, Debug)]
-pub struct Insert<M: ModelAble> {
+pub struct Insert<M: ArelAble> {
     value: Json,
     _marker: PhantomData<M>,
 }
 
-impl<M> StatementAble<M> for Insert<M> where M: ModelAble {
+impl<M> StatementAble<M> for Insert<M> where M: ArelAble {
     fn json_value(&self) -> Option<&Json> {
         Some(&self.value)
     }
@@ -40,7 +40,7 @@ impl<M> StatementAble<M> for Insert<M> where M: ModelAble {
     }
 }
 
-impl<M> Insert<M> where M: ModelAble {
+impl<M> Insert<M> where M: ArelAble {
     pub fn new(value: Json) -> Self {
         Self {
             value,
@@ -58,7 +58,7 @@ impl<M> Insert<M> where M: ModelAble {
 //     fn to_sql() {
 //         #[derive(Clone, Debug)]
 //         struct User {}
-//         impl ModelAble for User {}
+//         impl ArelAble for User {}
 //
 //         let insert = Insert::<User>::new(10);
 //         assert_eq!(insert.to_sql(), "Insert 10");
