@@ -1,17 +1,17 @@
 use serde_json::{Value as Json};
 use std::marker::PhantomData;
-use crate::traits::ModelAble;
+use crate::traits::ArelAble;
 use crate::statements::StatementAble;
 use crate::nodes::SqlLiteral;
 use crate::methods;
 
 #[derive(Clone, Debug)]
-pub struct Update<M: ModelAble> {
+pub struct Update<M: ArelAble> {
     value: Json,
     _marker: PhantomData<M>,
 }
 
-impl<M> StatementAble<M> for Update<M> where M: ModelAble {
+impl<M> StatementAble<M> for Update<M> where M: ArelAble {
     fn json_value(&self) -> Option<&Json> {
         Some(&self.value)
     }
@@ -37,7 +37,7 @@ impl<M> StatementAble<M> for Update<M> where M: ModelAble {
     }
 }
 
-impl<M> Update<M> where M: ModelAble {
+impl<M> Update<M> where M: ArelAble {
     pub fn new(value: Json) -> Self {
         Self {
             value,
@@ -48,13 +48,14 @@ impl<M> Update<M> where M: ModelAble {
 
 #[cfg(test)]
 mod tests {
+    use crate as arel;
     use super::*;
     use serde_json::{json};
     #[test]
     fn to_sql() {
-        #[derive(Clone, Debug)]
+        #[arel::arel]
+        #[allow(dead_code)]
         struct User {}
-        impl ModelAble for User {}
 
         let update = Update::<User>::new(json!({
             "name": "Tome",
@@ -62,7 +63,7 @@ mod tests {
             "active": true,
             "profile": null
         }));
-        assert_eq!(update.to_sql().unwrap(), "`users`.`active` = 1, `users`.`age` = 18, `users`.`name` = 'Tome', `users`.`profile` = null");
+        assert_eq!(update.to_sql().unwrap(), "`users`.`active` = 1, `users`.`age` = 18, `users`.`name` = 'Tome', `users`.`profile` = NULL");
 
         let update = Update::<User>::new(json!("users.active = 1"));
         assert_eq!(update.to_sql().unwrap(), "users.active = 1");
