@@ -10,16 +10,16 @@ pub use delete_manager::DeleteManager;
 
 use serde_json::{Value as Json, json};
 use crate::methods::type_to_pluralize_string;
-use crate::traits::ModelAble;
+use crate::traits::ArelAble;
 use std::marker::PhantomData;
 use crate::collectors::SqlString;
 use crate::visitors;
 use crate::statements::{r#where, having};
 use crate::methods;
-// pub trait ManagerStatement<M: ModelAble> {}
+// pub trait ManagerStatement<M: ArelAble> {}
 
 #[derive(Clone, Debug)]
-pub struct Table<M: ModelAble> {
+pub struct Table<M: ArelAble> {
     pub select_manager: Option<SelectManager<M>>,
     pub insert_manager: Option<InsertManager<M>>,
     pub update_manager: Option<UpdateManager<M>>,
@@ -27,18 +27,17 @@ pub struct Table<M: ModelAble> {
     _marker: PhantomData<M>,
 }
 
-impl<M> Table<M> where M: ModelAble {
+impl<M> Table<M> where M: ArelAble {
     /// Get Model's table name.
     ///
     /// # Examples
     ///
     /// ```
-    /// use arel::traits::ModelAble;
+    /// use arel::traits::ArelAble;
     /// use arel::table::Table;
     ///
-    /// #[derive(Clone, Debug)]
+    /// #[arel::arel]
     /// struct User {}
-    /// impl ModelAble for User {}
     /// assert_eq!(User::table_name(), "users");
     /// ```
     pub fn table_name() -> String {
@@ -313,23 +312,23 @@ impl<M> Table<M> where M: ModelAble {
     pub fn to_sql(&mut self) -> anyhow::Result<String> {
         let mut collector = SqlString::default();
         if let Some(insert_manager) = &self.insert_manager {
-            visitors::accept_insert_manager(insert_manager, &mut collector)?;
+            visitors::to_sql::accept_insert_manager(insert_manager, &mut collector)?;
         } else if let Some(update_manager) = &self.update_manager {
             let mut for_update_select_manager = None;
             if let Some(select_manager) = &mut self.select_manager {
                 select_manager.select(json!([M::primary_key()]));
                 for_update_select_manager = Some(select_manager);
             }
-            visitors::accept_update_manager(update_manager, for_update_select_manager, &mut collector)?;
+            visitors::to_sql::accept_update_manager(update_manager, for_update_select_manager, &mut collector)?;
         } else if let Some(delete_manager) = &self.delete_manager {
             let mut for_update_select_manager = None;
             if let Some(select_manager) = &mut self.select_manager {
                 select_manager.select(json!([M::primary_key()]));
                 for_update_select_manager = Some(select_manager);
             }
-            visitors::accept_delete_manager(delete_manager, for_update_select_manager, &mut collector)?;
+            visitors::to_sql::accept_delete_manager(delete_manager, for_update_select_manager, &mut collector)?;
         } else if let Some(select_manager) = &self.select_manager {
-            visitors::accept_select_manager(select_manager, &mut collector)?;
+            visitors::to_sql::accept_select_manager(select_manager, &mut collector)?;
         }  else {
             return Err(anyhow::anyhow!("Not support"));
         }
@@ -344,7 +343,7 @@ impl<M> Table<M> where M: ModelAble {
 //     fn it_works() {
 //         #[derive(Clone, Debug)]
 //         struct User {}
-//         impl ModelAble for User {}
+//         impl ArelAble for User {}
 //         impl User {
 //             fn new() -> Self {
 //                 Self {}
