@@ -6,17 +6,16 @@ use crate::table::Table;
 /// # Examples
 ///
 /// ```
-/// use arel::traits::ModelAble;
+/// use arel::traits::ArelAble;
 ///
-/// #[derive(Clone, Debug)]
+/// #[arel::arel]
 /// struct User {}
-/// impl ModelAble for User {}
 /// assert_eq!(User::table_name(), "users");
+/// #[arel::arel]
 /// struct Order {}
-/// impl ModelAble for Order {}
 /// assert_eq!(Order::table_name(), "orders");
 /// ```
-pub trait ModelAble: Sized {
+pub trait ArelAble: Sized {
     fn id() -> &'static str { Self::primary_key() }
     fn primary_key() -> &'static str { "id" }
     fn locking_column() -> &'static str { "lock_version" }
